@@ -1,3 +1,22 @@
+"""
+    Copyright (C) 2020-present, Murdo B. Maclachlan
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <https://www.gnu.org/licenses/>.
+    
+    Contact me at murdo@maclachlans.org.uk
+"""
+
 import datetime
 import json
 import sys
@@ -18,8 +37,9 @@ def getConfig(gvars):
         with open(gvars.home+"/.oscr/config.json") as configFile:
             try:
                 fromConfig = json.load(configFile)
-            except json.decoder.JSONDecodeError:
+            except json.decoder.JSONDecodeError as e:
                 doLog("Failed to get config; could not decode JSON file. Exiting.", gvars)
+                doLog(f"Error was: {e}", gvars)
                 sys.exit(0)
             gvars.config = fromConfig["config"][0]
             gvars = calculateEssentials(gvars)
@@ -43,13 +63,21 @@ def getConfig(gvars):
             "logUpdates": True,
             "os": os,
             "recur": True,
+            "regexBlacklist": [
+                "^claim(?!(.|\n)*treasure[\s-]*hunt)",
+                "^done(?!(.|\n)*treasure[\s-]*hunt)",
+                "^unclaim(?!(.|\n)*treasure[\s-]*hunt)"
+            ],
             "unit": [
                 "minute",
                 "minutes",
                 60
             ],
             "user": user,
-            "torOnly": True,
+            "useRegex": False,
+            "subredditList": [
+                "transcribersofreddit"
+            ],
             "wait": 10
         }
         outConfig = {}
@@ -135,6 +163,7 @@ def reformatIni(gvars):
                         success = True
                     elif line in ["[oscr]", "[oscr]          "]:
                         success = True
+                        doLog("praw.ini file already formatted to OSCR.", gvars)
                     file.write(line+"\n")
                 
                 # If successfully formatted to OSCR
@@ -166,4 +195,4 @@ def defineSavePath(gvars):
           
 # Retrieves the date the comment was posted at.
 def getDate(comment):
-    return comment.created_utc
+    return comment.created_utc
\ No newline at end of file
